@@ -103,7 +103,7 @@ open(OUTPUT, ">$file2") or die "Couldn't open $file2 for writing\n";
 
 foreach $lines (@lines)              # loop thru file
 { 
-	$lines =~ s~<\!DOCTYPE HTML PUBLIC (.+?)>~<?xml version=\"1.0\" encoding=\"ISO-8859-1\"?> \n<\!DOCTYPE html PUBLIC \"-\/\/W3C\/\/DTD XHTML 1.0 Strict\/\/EN\" \"http:\/\/www.w3.org\/TR\/xhtml1\/DTD\/xhtml1-strict.dtd\"> \n<html xmlns=\"http:\/\/www.w3.org\/1999\/xhtml\" xml:lang=\"en\" lang=\"en\">~ig;	
+	$lines =~ s~<\!DOCTYPE HTML PUBLIC (.+?)>~<?xml version=\"1.0\" encoding=\"ISO-8859-1\"?> \n<\!DOCTYPE html PUBLIC \"-\/\/W3C\/\/DTD XHTML 1.0 Strict\/\/EN\" \"http:\/\/www.w3.org\/TR\/xhtml1\/DTD\/xhtml1-strict.dtd\"> \n<html xmlns=\"http:\/\/www.w3.org\/1999\/xhtml\" xml:lang=\"en\">~ig;	
 	$lines =~ s/<HTML>//ig;	 	
 	$lines =~ s!<META CONTENT=(.+?) HTTP-EQUIV=(.+?)>!!ig;
 	$lines =~ s!<META CONTENT =(.+?) HTTP-EQUIV =(.+?)>!!ig;
@@ -129,15 +129,33 @@ foreach $lines (@lines)              # loop thru file
 	$lines =~ s/<P>/<p>/ig;	 	
 	$lines =~ s/<\/P>/<\/p>/ig;	
 	$lines =~ s!<IMG (.+?)>!<img $1\/>!mig;
+	$lines =~ s!<\bIMG\b!<img!ig;
+	$lines =~ s!<\bcolor\b!<color!ig;
 	$lines =~ s/SRC/src/ig;
+	$lines =~ s/src=\"(\w+)\"/src=\"$1\"/ig;
 	$lines =~ s/CLASS =|CLASS=/class=/ig;
+	$lines =~ s/class=(\w+)/class=\"$1\"/ig;	
 	$lines =~ s/ALT =|ALT=/alt=/ig;
+	$lines =~ s/onMouseOut/onmouseout/ig;
+	$lines =~ s/onMouseOver/onmouseover/ig;
+	$lines =~ s/onMouseDown/onmousedown/ig;
+	$lines =~ s/onMouseMove/onmousemove/ig;
+	$lines =~ s/onMouseUp/onmouseup/ig;	
+	$lines =~ s/onClick/onclick/ig;
+	$lines =~ s/onDblClick/ondblclick/ig;
+	$lines =~ s/onKeyDown/onkeydown/ig;
+	$lines =~ s/onKeyPress/onkeypress/ig;
+	$lines =~ s/onKeyUp/onkeyup/ig;	
+	$lines =~ s/alt=(\w+)/alt=\"$1\"/ig;	
 	$lines =~ s/\bHEIGHT\b/height/ig;
+	$lines =~ s/height=(\w+)/height=\"$1\"/ig;	
 	$lines =~ s/\bWIDTH\b/width/ig;
+	$lines =~ s/width=(\w+)/width=\"$1\"/ig;	
 	$lines =~ s/\bDIV\b/div/ig;
 	$lines =~ s/<SPAN/<span/ig;
 	$lines =~ s/<\/SPAN/<\/span/ig;
 	$lines =~ s/ID =|ID=/id=/ig;
+	$lines =~ s/id=\"(\w+)\"/id=\"$1\"/ig;	
 	$lines =~ s/<LI/<li/ig;
 	$lines =~ s/<\/LI/<\/li/ig;
 	$lines =~ s/<A/<a/ig;
@@ -152,7 +170,7 @@ foreach $lines (@lines)              # loop thru file
 	$lines =~ s/<FORM/<form/ig;	
 	$lines =~ s/<UL/<ul/ig;	 	
 	$lines =~ s/<\/UL>/<\/ul>/ig;		
-	$lines =~ s/<B>/<b>/ig;	 	
+	$lines =~ s/<B>/<span style="font-weight: bold">/ig;	 	
 	$lines =~ s/<\/B>/<\/b>/ig;		
 	$lines =~ s/\bMENU\b/menu/ig;
 	$lines =~ s/\bSMALL\b/small/ig;
@@ -170,7 +188,9 @@ foreach $lines (@lines)              # loop thru file
 	$lines =~ s/<\/CODE/<\/code/ig;	
 	$lines =~ s/<DFN/<dfn/ig;
 	$lines =~ s/<\/DFN/<\/dfn/ig;	
-	$lines =~ s/<PRE/<pre/ig;
+	$lines =~ s/<KBD/<kbd/ig;
+	$lines =~ s/<\/KBD/<\/kbd/ig;		
+	$lines =~ s/<PRE/<pre/ig;	
 	$lines =~ s/<\/PRE/<\/pre/ig;	
 	$lines =~ s/<Q/<q/ig;
 	$lines =~ s/<\/Q/<\/q/ig;	
@@ -217,6 +237,7 @@ foreach $lines (@lines)              # loop thru file
 	$lines =~ s/\bISMAP\b/ismap/ig;
 	$lines =~ s/\bNOSCRIPT\b/noscript/ig;
 	$lines =~ s/\bSCRIPT\b/script/ig;
+	$lines =~ s!<SCRIPT type="text/javascript"|SCRIPT language=\"JavaScript\">!<script type=\"text\/javascript\">!ig;	
 	$lines =~ s/<BASE/<base/ig;
 	$lines =~ s/<\/BASE/<\/base/ig;	
 	$lines =~ s/<RUBY/<ruby/ig;
@@ -254,11 +275,13 @@ foreach $lines (@lines)              # loop thru file
 	$lines =~ s/\bSTARTTIME\b/starttime/ig;
 	$lines =~ s/\bENDTIME\b/endtime/ig;	
 	$lines =~ s/ALIGN =|ALIGN=/align=/ig; 	
+	$lines =~ s/align=\"(\w+)\"/align=\"\L$1\"/ig; 		
 	$lines =~ s/SUMMARY =|VOLUME=/summary=/ig; 
 	$lines =~ s/DIR =|DIR=/dir=/ig; 		
 	$lines =~ s/dir=\"(\w+)\"/dir=\"\L$1\"/ig; 		
-	$lines =~ s/LANG =|LANG=/lang=/ig; 		
-	$lines =~ s/lang=\"(\w+)\"/lang=\"\L$1\"/ig; 			
+	$lines =~ s/LANG =|LANG=/xml:lang=/ig; 		
+	$lines =~ s/xml:lang=\"(\w+)\"/xml:lang=\"\L$1\"/ig; 			
+	$lines =~ s/xml:lang=\"(\w+)\" lang=\"(\w+)\"/xml:lang=\"\L$1\"/ig;
 	$lines =~ s/SPAN =|SPAN=/span=/ig; 
 	$lines =~ s/<TABLE/<table/ig;
 	$lines =~ s/<\/TABLE/<\/table/ig;	
@@ -281,8 +304,16 @@ foreach $lines (@lines)              # loop thru file
 	$lines =~ s/\bNOWRAP\b/nowrap/ig; 
 	$lines =~ s/AXIS =|AXIS=/axis=/ig; 
 	$lines =~ s/STYLE =|STYLE=/style=/ig; 
-	$lines =~ s/BGCOLOR =|BGCOLOR=/bgcolor=/ig; 
-	$lines =~ s/COLOR =|COLOR=/color=/ig;
+	$lines =~ s/\bBACKGROUND/background/ig; 
+	$lines =~ s/\bPADDING/padding/ig; 
+	$lines =~ s/\bTOP/top/ig; 
+	$lines =~ s/\bLEFT/left/ig; 
+	$lines =~ s/\bRIGHT/right/ig; 
+	$lines =~ s/\bBOTTOM/bottom/ig; 
+	$lines =~ s/\bIMAGE/image/ig; 
+	$lines =~ s/REPEAT\b/repeat/ig; 	
+	$lines =~ s/BGcolor =|BGcolor=/bgcolor=/ig; 
+	$lines =~ s/color =|color=/color=/ig;
 	$lines =~ s/VALIGN =|VALIGN=/valign=/ig;
 	$lines =~ s/CHAR =|CHAR=/char=/ig;
 	$lines =~ s/CHAROFF =|CHAROFF-/charoff=/ig;
@@ -306,6 +337,7 @@ foreach $lines (@lines)              # loop thru file
 	$lines =~ s/VLINK =|VLINK=/vlink=/ig;
 	$lines =~ s/ALINK =|ALINK=/alink=/ig;	
 	$lines =~ s/<INPUT (.+?)>/<input $1\/>/ig;			
+	$lines =~ s/<HR (.+?)>/<hr $1\/>/ig;			
 	$lines =~ s/<BUTTON/<button/ig;
 	$lines =~ s/<\/button/<\/button/ig;					
 	$lines =~ s/<SELECT/<select/ig;
@@ -332,10 +364,12 @@ foreach $lines (@lines)              # loop thru file
 	$lines =~ s/VALUE =|VALUE=/value=/ig;
 	$lines =~ s/<FIELDSET/<fieldset/ig;
 	$lines =~ s/<\/FIELDSET/<\/fieldset/ig;	
-	$lines =~ s/FOR =|FOR=/for=/ig;	
+	$lines =~ s/FOR =|FOR=/for=/ig;		
 	$lines =~ s/MAXLENGTH =|MAXLENGTH=/maxlength=/ig;	
 	$lines =~ s/SIZE =|SIZE=/size=/ig;	
-			
+	$lines =~ s/\bMARGIN\b/margin/ig;	
+	$lines =~ s!\/\/>!/>!g;
+	
 	print OUTPUT $lines;
 }
 
@@ -363,15 +397,15 @@ foreach $lines (@lines)              # loop thru file
 	$lines =~ s/NAME/name/ig;
 	$lines =~ s/LINK/link/ig;		
 	$lines =~ s/BODY/body/ig;		
-	$lines =~ s/P/p/ig;	 				 		
+	$lines =~ s/\bP\b/p/ig;	 				 		
 	$lines =~ s/HEIGHT/height/ig;
 	$lines =~ s/WIDTH/width/ig;
 	$lines =~ s/DIV/div/ig;
 	$lines =~ s/SPAN/span/ig;
 	$lines =~ s/IMG/img/ig;
-	$lines =~ s/ID/id/ig;
-	$lines =~ s/LI/li/ig;
-	$lines =~ s/A/a/ig;
+	$lines =~ s/\bID\b/id/ig;
+	$lines =~ s/\bLI\b/li/ig;
+	$lines =~ s/\bA\b/a/ig;
 	$lines =~ s/BR/br/ig;	
 	$lines =~ s/FORM/form/ig;
 	$lines =~ s/UL/ul/ig;
@@ -392,37 +426,33 @@ foreach $lines (@lines)              # loop thru file
 	$lines =~ s/THEAD/thead/ig;	
 	$lines =~ s/TFOOT/tfoot/ig;	
 	$lines =~ s/COLGROUP/colgroup/ig;	
-	$lines =~ s/COL/col/ig;			
-	$lines =~ s/EM/em/ig;	
-	$lines =~ s/B/b/ig;	
-	$lines =~ s/I/i/ig;	
-	$lines =~ s/U/u/ig;	
+	$lines =~ s/COL/col/ig;				
 	$lines =~ s!H(\d{1})!h$1!ig;
 	$lines =~ s/BLINK/blink/ig;	
 	$lines =~ s/EMBED/embed/ig;			
-	$lines =~ s/EM/em/ig;	
-	$lines =~ s/B/b/ig;	
-	$lines =~ s/I/i/ig;	
-	$lines =~ s/U/u/ig;	
+	$lines =~ s/\bEM\b/em/ig;	
+	$lines =~ s/\bB\b/b/ig;	
+	$lines =~ s/\bI\b/i/ig;	
+	$lines =~ s/\bU\b/u/ig;	
 	$lines =~ s/BLINK/blink/ig;	
 	$lines =~ s/EMBED/embed/ig;				
 	$lines =~ s/NOWRAP/nowrap/ig; 
 	$lines =~ s/AXIS/axis/ig;	
-	$lines =~ s/BGCOLOR/bgcolor/ig;
-	$lines =~ s!COLOR!color!ig;
-	$lines =~ s!VALIGN!valign!ig;
-	$lines =~ s!CHAR!char!ig;
-	$lines =~ s!CHAROFF!charoff!ig;
-	$lines =~ s!FRAME!frame!ig;
-	$lines =~ s!RULES!rules!ig;
-	$lines =~ s!BORDER!border!ig;
-	$lines =~ s!CELLSPACING!cellspacing!ig;
-	$lines =~ s!CELLPADDING!cellpadding!ig;
-	$lines =~ s!HEADERS!headers!ig;
-	$lines =~ s!TEXT!text!ig;
-	$lines =~ s!BACKGROUND!background!ig;
-	$lines =~ s!VLINK!vlink!ig;
-	$lines =~ s!ALINK!alink!ig;		
+	$lines =~ s/BGcolor/bgcolor/ig;
+	$lines =~ s/color/color/ig;
+	$lines =~ s/VALIGN/valign/ig;
+	$lines =~ s/CHAR/char/ig;
+	$lines =~ s/CHAROFF/charoff/ig;
+	$lines =~ s/FRAME/frame/ig;
+	$lines =~ s/RULES/rules/ig;
+	$lines =~ s/BORDER/border/ig;
+	$lines =~ s/CELLSPACING/cellspacing/ig;
+	$lines =~ s/CELLPADDING/cellpadding/ig;
+	$lines =~ s/HEADERS/headers/ig;
+	$lines =~ s/TEXT/text/ig;
+	$lines =~ s/BACKGROUND/background/ig;
+	$lines =~ s/VLINK/vlink/ig;
+	$lines =~ s/ALINK/alink/ig;		
 	$lines =~ s/INPUT/input/ig;	
 	$lines =~ s/BUTTON/button/ig;	
 	$lines =~ s/SELECT/select/ig;	
@@ -437,7 +467,7 @@ foreach $lines (@lines)              # loop thru file
 	$lines =~ s/CODE/code/ig;
 	$lines =~ s/DFN/dfn/ig;	
 	$lines =~ s/PRE/pre/ig;	
-	$lines =~ s/Q/q/ig;	
+	$lines =~ s/\bQ\b/q/ig;	
 	$lines =~ s/SAMP/samp/ig;	
 	$lines =~ s/PRE/pre/ig;	
 	$lines =~ s/STRONG/strong/ig;	
@@ -469,7 +499,36 @@ foreach $lines (@lines)              # loop thru file
 	$lines =~ s/RB/rb/ig;	
 	$lines =~ s/RT/rt/ig;	
 	$lines =~ s/RP/rp/ig;	
-			
+	$lines =~ s/MARGIN/margin/ig;
+	$lines =~ s/TOP/top/ig;
+	$lines =~ s/BOTTOM/bottom/ig;
+	$lines =~ s/RIGHT/right/ig;
+	$lines =~ s/LEFT/left/ig;
+	$lines =~ s/FONT/font/ig;
+	$lines =~ s/HOVER/hover/ig;
+	$lines =~ s/WEIGHT/weight/ig;
+	$lines =~ s/SIZE/size/ig;
+	$lines =~ s/CURSOR/cursor/ig;
+	$lines =~ s/URL/url/ig;
+	$lines =~ s/STYLE/style/ig;
+	$lines =~ s/FAMILY/family/ig;
+	$lines =~ s/COLLAPSE/collapse/ig;			
+	$lines =~ s/ALIGN/align/ig;		
+	$lines =~ s/DECORATION/decoration/ig;		
+	$lines =~ s/LIST/list/ig;		
+	$lines =~ s/IMAGE/image/ig;		
+	$lines =~ s/REPEAT/repeat/ig;		
+	$lines =~ s/PADDING/padding/ig;		
+	$lines =~ s/LINE/line/ig;		
+	$lines =~ s/DISPLAY/display/ig;		
+	$lines =~ s/FILTER/filter/ig;		
+	$lines =~ s/TYPE/type/ig;		
+	$lines =~ s/FLOAT/float/ig;
+	$lines =~ s/POSITION/position/ig;
+	$lines =~ s/INDENT/indent/ig;
+	$lines =~ s/\bHR\b/indent/ig;
+	$lines =~ s/VARIANT/variant/ig;
+				
 	print OUTPUT $lines;
 }
 
